
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.27.4.post1',
    'branch_nick': 'release-1.27',
    'revision_id': 'b9b10e86146247c8610816ea791704ab147b64c0',
    'revno': 11210
}
